@@ -3,13 +3,13 @@ ldif - generate and parse LDIF data (see RFC 2849)
 
 See http://www.python-ldap.org/ for details.
 
-$Id: ldif.py,v 1.97 2016/07/17 19:38:32 stroeder Exp $
+$Id: ldif.py,v 1.101 2016/11/11 14:41:07 stroeder Exp $
 
 Python compability note:
 Tested with Python 2.0+, but should work with Python 1.5.2+.
 """
 
-__version__ = '2.4.26'
+__version__ = '2.4.28'
 
 __all__ = [
   # constants
@@ -297,10 +297,7 @@ class LDIFParser:
     self.line_counter = self.line_counter + 1
     self.byte_counter = self.byte_counter + len(s)
     if not s:
-      raise EOFError('EOF reached after %d lines (%d bytes)' % (
-        self.line_counter,
-        self.byte_counter,
-      ))
+      return None
     elif s[-2:]=='\r\n':
       return s[:-2]
     elif s[-1:]=='\n':
@@ -312,6 +309,11 @@ class LDIFParser:
     """
     Unfold several folded lines with trailing space into one line
     """
+    if self._last_line is None:
+      raise EOFError('EOF reached after %d lines (%d bytes)' % (
+        self.line_counter,
+        self.byte_counter,
+      ))
     unfolded_lines = [ self._last_line ]
     next_line = self._readline()
     while next_line and next_line[0]==' ':
@@ -498,7 +500,10 @@ class LDIFParser:
             # we now have the attribute name to be modified
             modattr = v
             modvalues = []
-            k,v = next_key_and_value()
+            try:
+              k,v = next_key_and_value()
+            except EOFError:
+              k,v = None,None
             while k==modattr:
               modvalues.append(v)
               try:
